# Luxsci::SecureFormApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_secure_form_database_file**](SecureFormApi.md#delete_secure_form_database_file) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
[**delete_secure_form_database_row**](SecureFormApi.md#delete_secure_form_database_row) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
[**get_secure_form**](SecureFormApi.md#get_secure_form) | **GET** /account/{accountId}/secureforms/{formID} | 
[**get_secure_form_database_file**](SecureFormApi.md#get_secure_form_database_file) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
[**get_secure_form_database_posts**](SecureFormApi.md#get_secure_form_database_posts) | **GET** /account/{accountId}/secureforms/{formID}/db | 
[**get_secure_form_database_row**](SecureFormApi.md#get_secure_form_database_row) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
[**get_secure_form_database_rows**](SecureFormApi.md#get_secure_form_database_rows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows | 
[**get_secure_form_list**](SecureFormApi.md#get_secure_form_list) | **GET** /account/{accountId}/secureforms | 

# **delete_secure_form_database_file**
> InlineResponse201 delete_secure_form_database_file(account_id, form_id, row_index, file_index, opts)



This function is used to remove a file associated with a row in your SecureForm database. {{ACL: Account: SecureForm Database - Delete}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
row_index = 'row_index_example' # String | 
file_index = 'file_index_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_secure_form_database_file(account_id, form_id, row_index, file_index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->delete_secure_form_database_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **row_index** | **String**|  | 
 **file_index** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_secure_form_database_row**
> InlineResponse201 delete_secure_form_database_row(account_id, form_id, index, opts)



This function allows you to delete a row from your SecureForm database, based on the row index. This function will delete the row and any associated files.  This API call is audited: a record will be made of the particular API Integration and IP address that “deleted” each matching row (also implying that any associated files have been removed). {{ACL: Account: SecureForm Database - Delete}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
index = 'index_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_secure_form_database_row(account_id, form_id, index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->delete_secure_form_database_row: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **index** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form**
> InlineResponse20067 get_secure_form(account_id, form_id, opts)



Returns details on a specific SecureForm configuration, based on the configuration’s unique ID.  {{ACL: Account: SecureForm Configuration}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 

### Return type

[**InlineResponse20067**](InlineResponse20067.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form_database_file**
> InlineResponse20071 get_secure_form_database_file(account_id, form_id, row_index, file_index, opts)



This function is used to retrieve a file associated with a row in your SecureForm database. You will need the row index and the file ID (which you can retrieve by reading the row data using other API calls).  If the file was encrypted at rest in the database, it will be decrypted for you.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each file. {{ACL: Account: SecureForm Database - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
row_index = 'row_index_example' # String | 
file_index = 'file_index_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_database_file(account_id, form_id, row_index, file_index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **row_index** | **String**|  | 
 **file_index** | **String**|  | 

### Return type

[**InlineResponse20071**](InlineResponse20071.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form_database_posts**
> InlineResponse20068 get_secure_form_database_posts(account_id, form_id, opts)



Returns details on the posts currently stored in the database table associated with a specific SecureForm configuration. This function is recommended for use when synchronizing or periodically downloading new rows to an external source: it allows you to quickly and easily see what, if any, entries are new relative to your last actions (if you saved the last index or date when you previously downloaded data).  You can optionally pass one or more parameters to narrow down the scope of what rows are examined to produce the summary results. By default, all table rows are examined. All criteria passed as parameters are used; it is possible (and easy) to specify mutually exclusive parameters that result in no rows being examined (e.g. all rows with an index greater than 100 and less than 50). {{ACL: Account: SecureForm Database - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  after_index: 56, # Integer | All rows whose index is greater than the specified value
  before_date: 'before_date_example', # String | DATETIME. All rows added before the specified date time
  before_index: 56, # Integer | All rows whose index is less than the specified value
  from_date: 'from_date_example', # String | DATETIME. All rows added on or after the specified date time
  from_index: 56, # Integer | All rows whose index is greater than or equal to the specified value.
  through_date: 'through_date_example', # String | DATETIME. All rows added on or before the specified date time
  through_index: 56, # Integer | All rows whose index is less than or equal to the specified value.
}

begin
  result = api_instance.get_secure_form_database_posts(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_posts: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **after_date** | **String**| DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional] 
 **after_index** | **Integer**| All rows whose index is greater than the specified value | [optional] 
 **before_date** | **String**| DATETIME. All rows added before the specified date time | [optional] 
 **before_index** | **Integer**| All rows whose index is less than the specified value | [optional] 
 **from_date** | **String**| DATETIME. All rows added on or after the specified date time | [optional] 
 **from_index** | **Integer**| All rows whose index is greater than or equal to the specified value. | [optional] 
 **through_date** | **String**| DATETIME. All rows added on or before the specified date time | [optional] 
 **through_index** | **Integer**| All rows whose index is less than or equal to the specified value. | [optional] 

### Return type

[**InlineResponse20068**](InlineResponse20068.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form_database_row**
> InlineResponse20070 get_secure_form_database_row(account_id, form_id, index, opts)



This function works the same as “Get SecureForm Database Rows”, except that you specify the row index and get back up to 1 row. This index is the `\\_\\_index\\_\\_` field for the row.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  {{ACL: Account: SecureForm Database - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
index = 'index_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_database_row(account_id, form_id, index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_row: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **index** | **String**|  | 

### Return type

[**InlineResponse20070**](InlineResponse20070.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form_database_rows**
> InlineResponse20069 get_secure_form_database_rows(account_id, form_id, opts)



This function returns the actual content of all database rows matching your query. Encrypted database fields will be automatically decrypted and the actual values of the fields returned.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  You can optionally pass one or more parameters to narrow down the scope of what rows are returned. These parameters are the same as those for “Get SecureForm Database Info”. {{ACL: Account: SecureForm Database - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  after_index: 56, # Integer | All rows whose index is greater than the specified value
  before_date: 'before_date_example', # String | DATETIME. All rows added before the specified date time
  before_index: 56, # Integer | All rows whose index is less than the specified value
  from_date: 'from_date_example', # String | DATETIME. All rows added on or after the specified date time
  from_index: 56, # Integer | All rows whose index is greater than or equal to the specified value.
  through_date: 'through_date_example', # String | DATETIME. All rows added on or before the specified date time
  through_index: 56, # Integer | All rows whose index is less than or equal to the specified value.
}

begin
  result = api_instance.get_secure_form_database_rows(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_rows: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **form_id** | **String**|  | 
 **after_date** | **String**| DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional] 
 **after_index** | **Integer**| All rows whose index is greater than the specified value | [optional] 
 **before_date** | **String**| DATETIME. All rows added before the specified date time | [optional] 
 **before_index** | **Integer**| All rows whose index is less than the specified value | [optional] 
 **from_date** | **String**| DATETIME. All rows added on or after the specified date time | [optional] 
 **from_index** | **Integer**| All rows whose index is greater than or equal to the specified value. | [optional] 
 **through_date** | **String**| DATETIME. All rows added on or before the specified date time | [optional] 
 **through_index** | **Integer**| All rows whose index is less than or equal to the specified value. | [optional] 

### Return type

[**InlineResponse20069**](InlineResponse20069.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_form_list**
> InlineResponse20066 get_secure_form_list(account_id, opts)



Return a list of all SecureForm configurations currently defined in your account. {{ACL: Account: SecureForm Configuration}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_list(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 

### Return type

[**InlineResponse20066**](InlineResponse20066.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



