# Luxsci::ServersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_server_status**](ServersApi.md#get_server_status) | **GET** /account/{accountId}/server/{serverId} | 
[**get_servers**](ServersApi.md#get_servers) | **GET** /account/{accountId}/servers | 
[**server_empty_all_email_queues**](ServersApi.md#server_empty_all_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
[**server_empty_email_queues**](ServersApi.md#server_empty_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
[**set_server_sendng_rate**](ServersApi.md#set_server_sendng_rate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 

# **get_server_status**
> InlineResponse20075 get_server_status(account_id, server_id, opts)



This report allows you to retrieve specific current status of a specific server. This request will actually directly interrogate the server for some of this information; in situations where the server is overloaded or down or very slow, *this API will fail.*  {{ACL: Account: Servers - Report}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  result = api_instance.get_server_status(account_id, server_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->get_server_status: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **server_id** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

[**InlineResponse20075**](InlineResponse20075.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_servers**
> InlineResponse20074 get_servers(account_id, opts)



This report allows you to retrieve general information about all of the dedicated servers associated with your account. {{ACL: Account: Servers - Report}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_servers(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->get_servers: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 

### Return type

[**InlineResponse20074**](InlineResponse20074.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **server_empty_all_email_queues**
> server_empty_all_email_queues(account_id, server_id, opts)



This command allows you to remove all email messages that are queued.  These are the mail_queue_trying and mail_queue_unprocessed messages returned by the server status call.  Messages that have not yet been processed will be deleted by this call. 

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  api_instance.server_empty_all_email_queues(account_id, server_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->server_empty_all_email_queues: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **server_id** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

nil (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **server_empty_email_queues**
> server_empty_email_queues(account_id, server_id, opts)



This command allows you to remove all email messages that are queued and trying to be delivered to recipients.  These are the mail_queue_trying messages returned by the server status call.  Messages that have not yet been processed are not deleted. 

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  api_instance.server_empty_email_queues(account_id, server_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->server_empty_email_queues: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **server_id** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

nil (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **set_server_sendng_rate**
> set_server_sendng_rate(account_idserver_id, opts)



This command allows you to update the email processing rate limits for this server.  These rate limits govern the rate at which messages are processed and delivered to the queues for delivery to recipients, for IP Warmup purposes.  These settings to not impact messages already processed trying to be delivered to recipients.

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
  body: Luxsci::ServerIdSendingRateBody.new # ServerIdSendingRateBody | 
}

begin
  api_instance.set_server_sendng_rate(account_idserver_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->set_server_sendng_rate: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **server_id** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 
 **body** | [**ServerIdSendingRateBody**](ServerIdSendingRateBody.md)|  | [optional] 

### Return type

nil (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined



